# THIS FILE IS GENERATED FROM ENSTALLER SETUP.PY
version = '4.8.2'
full_version = '4.8.2'
git_revision = '8a96fe9c0ac35b3db2b690f9fa898bf38a450d2b'
is_released = True

if not is_released:
    version = full_version
